@@ -294,8 +294,7 @@ sub DynamicFieldGet {
     }
 
     # get yaml object
-    my $YAMLObject      = $Kernel::OM->Get('Kernel::System::YAML');
-    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
+    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
 
     my %Data;
     while ( my @Data = $DBObject->FetchrowArray() ) {
@@ -903,7 +902,7 @@ Returns:
             CreateTime    => '2010-09-11 10:08:00',
             ChangeTime    => '2011-01-01 01:01:01',
         },
-        ...
+        # ...
     );
 
 =cut
@@ -1695,16 +1694,32 @@ sub _DynamicFieldReorder {
 
 =head2 _SanitizeConfig()
 
-Currently only removes JavaScript code from configured regular expression error messages.
+This function cleans up the config:
 
-    $DynamicFieldObject->_SanitizeConfig(
+Removes JavaScript code from configured regular expression error messages:
+
+    my $Success = $DynamicFieldObject->_SanitizeConfig(
 
         # 'Config' part of a dynamic field config hash returned by DynamicFieldGet()
         # or given to DynamicFieldAdd() and -Update()
         Config => $Config,
     );
 
-    Returns 1.
+
+Removes reserved keywords in link configuration:
+
+    my $Success = $DynamicFieldObject->_SanitizeConfig(
+        Config => {
+            Link => 'https://www.znuny.org/[% Data.Link %]/[% Data.LinkPreview %]/[% Data.Title %]/[% Data.Value %]'
+        },
+    );
+
+    $Config->{Link} = 'https://www.znuny.org////';
+
+
+Return:
+
+    my $Success = 1;
 
 =cut
 
@@ -1725,13 +1740,7 @@ sub _SanitizeConfig {
         return;
     }
 
-    if ( !IsHashRefWithData( $Param{Config} ) ) {
-        $LogObject->Log(
-            Priority => 'error',
-            Message  => "Parameter 'Config' must be a hash ref with data!",
-        );
-        return;
-    }
+    return if !IsHashRefWithData( $Param{Config} );
 
     # Remove JavaScript, etc. from regex error messages.
     # This prevents execution of arbitrary JavaScript when showing
@@ -1757,6 +1766,13 @@ sub _SanitizeConfig {
         $RegExConfig->{ErrorMessage} = $SafeRegExErrorMessage{String} // '';
     }
 
+    my @ReservedKeywords = (qw(Link LinkPreview Title Value));
+    if ( $Param{Config}->{Link} ) {
+        for my $Keyword (@ReservedKeywords) {
+            $Param{Config}->{Link} =~ s{\[\% Data\.$Keyword \%\]}{}g;
+        }
+    }
+
     return 1;
 }
 
