@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -169,7 +169,7 @@ run a generic agent job
     $GenericAgentObject->JobRun(
         Job          => 'JobName',
         OnlyTicketID => 123,     # (optional) for event based Job execution
-        SleepTime    => 100_000  # (optional) sleeptime per ticket in microseconds
+        SleepTime    => 100_000, # (optional) sleeptime per ticket in microseconds
         UserID       => 1,
     );
 
@@ -740,7 +740,7 @@ adds a new job to the database
         Name => 'JobName',
         Data => {
             Queue => 'SomeQueue',
-            ...
+            # ...
             Valid => 1,
         },
         UserID => 123,
@@ -979,7 +979,7 @@ sub _JobRunTicket {
         );
 
         if ( IsHashRefWithData( \%Ticket ) ) {
-            my %CustomerUserData = ();
+            my %CustomerUserData;
             if ( IsStringWithData( $Ticket{CustomerUserID} ) ) {
                 %CustomerUserData = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerUserDataGet(
                     User => $Ticket{CustomerUserID},
@@ -1447,37 +1447,6 @@ sub _JobRunTicket {
         );
     }
 
-    # cmd
-    my $AllowCustomScriptExecution
-        = $Kernel::OM->Get('Kernel::Config')->Get('Ticket::GenericAgentAllowCustomScriptExecution') || 0;
-
-    if ( $Param{Config}->{New}->{CMD} && $AllowCustomScriptExecution ) {
-        if ( $Self->{NoticeSTDOUT} ) {
-            print "  - Execute '$Param{Config}->{New}->{CMD}' for Ticket $Ticket.\n";
-        }
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "Execute '$Param{Config}->{New}->{CMD}' for Ticket $Ticket.",
-        );
-        system("$Param{Config}->{New}->{CMD} $Param{TicketNumber} $Param{TicketID} ");
-
-        if ( $? ne 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'notice',
-                Message  => "Command returned a nonzero return code: rc=$?, err=$!",
-            );
-        }
-    }
-    elsif ( $Param{Config}->{New}->{CMD} && !$AllowCustomScriptExecution ) {
-        if ( $Self->{NoticeSTDOUT} ) {
-            print "  - Execute '$Param{Config}->{New}->{CMD}' is not allowed by the system configuration..\n";
-        }
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "Execute '$Param{Config}->{New}->{CMD}' is not allowed by the system configuration..",
-        );
-    }
-
     # delete ticket
     if ( $Param{Config}->{New}->{Delete} ) {
         if ( $Self->{NoticeSTDOUT} ) {
